@@ -1,5 +1,5 @@
 from .base import Connection, Parameter, ParameterGroup, ParameterType
-from .engine import Engine
+from .engine import Engine, current_engine
 
 __all__ = [
     "Engine",
@@ -7,4 +7,5 @@ __all__ = [
     "ParameterGroup",
     "ParameterType",
     "Connection",
+    "current_engine",
 ]
