@@ -6,7 +6,7 @@ if "NOMIGEN_TEST_CREDENTIALS" in os.environ:
 else:
     creds_dir = "/nomnom/test_config"
 
-if "CI" in os.environ:
+if "ENGINE_TEST_CREDS" in os.environ:
     creds_path = os.environ["ENGINE_TEST_CREDS"]
 else:
     creds_path = os.path.join(creds_dir, "nomigen_test_credentials.json")
